@@ -4,6 +4,8 @@ Created on Aug 18, 2014
 @author: akusoka1
 '''
 
-from .elm_naive import ELM_Naive
+from .elm_basic import ELM_Basic
 from .elm import ELM
-from .data_loader import batchX, batchT, encode, decode, meanstdX, c_dictT
\ No newline at end of file
+from .data_loader import batchX, batchT, encode, decode, meanstdX, c_dictT
+from .h5tools import h5write, h5read
+from .neuron_generator import gen_neurons
\ No newline at end of file
